This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] gcc: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2002-09-26  Kazu Hirata  <kazu@cs.umass.edu>

	* c-common.h: Follow spelling conventions.
	* cpplex.c: Likewise.
	* cpplib.h: Likewise.
	* gthr-dce.h: Likewise.
	* gthr-posix.h: Likewise.
	* optabs.c: Likewise.
	* output.h: Likewise.
	* profile.c: Likewise.
	* protoize.c: Likewise.
	* ra-rewrite.c: Likewise.
	* real.c: Likewise.
	* recog.c: Likewise.
	* reg-stack.c: Likewise.
	* regclass.c: Likewise.
	* regmove.c: Likewise.
	* reload.c: Likewise.
	* reload.h: Likewise.
	* reload1.c: Likewise.
	* reorg.c: Likewise.
	* resource.c: Likewise.
	* rtl.h: Likewise.
	* rtlanal.c: Likewise.

Index: c-common.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/c-common.h,v
retrieving revision 1.162
diff -u -r1.162 c-common.h
--- c-common.h	23 Sep 2002 15:00:42 -0000	1.162
+++ c-common.h	26 Sep 2002 22:18:09 -0000
@@ -43,7 +43,7 @@
 */
 
 /* Reserved identifiers.  This is the union of all the keywords for C,
-   C++, and Objective C.  All the type modifiers have to be in one
+   C++, and Objective-C.  All the type modifiers have to be in one
    block at the beginning, because they are used as mask bits.  There
    are 27 type modifiers; if we add many more we will have to redesign
    the mask mechanism.  */
@@ -93,7 +93,7 @@
   /* casts */
   RID_CONSTCAST, RID_DYNCAST, RID_REINTCAST, RID_STATCAST,
 
-  /* Objective C */
+  /* Objective-C */
   RID_ID,          RID_AT_ENCODE,    RID_AT_END,
   RID_AT_CLASS,    RID_AT_ALIAS,     RID_AT_DEFS,
   RID_AT_PRIVATE,  RID_AT_PROTECTED, RID_AT_PUBLIC,
Index: cpplex.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cpplex.c,v
retrieving revision 1.214
diff -u -r1.214 cpplex.c
--- cpplex.c	22 Sep 2002 02:03:16 -0000	1.214
+++ cpplex.c	26 Sep 2002 22:18:11 -0000
@@ -1329,7 +1329,7 @@
     case '}': result->type = CPP_CLOSE_BRACE; break;
     case ';': result->type = CPP_SEMICOLON; break;
 
-      /* @ is a punctuator in Objective C.  */
+      /* @ is a punctuator in Objective-C.  */
     case '@': result->type = CPP_ATSIGN; break;
 
     case '$':
Index: cpplib.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cpplib.h,v
retrieving revision 1.236
diff -u -r1.236 cpplib.h
--- cpplib.h	22 Sep 2002 02:03:17 -0000	1.236
+++ cpplib.h	26 Sep 2002 22:18:12 -0000
@@ -123,7 +123,7 @@
   OP(CPP_SCOPE,		"::")			\
   OP(CPP_DEREF_STAR,	"->*")			\
   OP(CPP_DOT_STAR,	".*")			\
-  OP(CPP_ATSIGN,	"@")  /* used in Objective C */ \
+  OP(CPP_ATSIGN,	"@")  /* used in Objective-C */ \
 \
   TK(CPP_NAME,		SPELL_IDENT)	/* word */			\
   TK(CPP_NUMBER,	SPELL_NUMBER)	/* 34_be+ta  */			\
Index: gthr-dce.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gthr-dce.h,v
retrieving revision 1.17
diff -u -r1.17 gthr-dce.h
--- gthr-dce.h	4 Jun 2002 11:30:42 -0000	1.17
+++ gthr-dce.h	26 Sep 2002 22:18:12 -0000
@@ -74,7 +74,7 @@
 #pragma weak pthread_mutex_unlock
 
 #ifdef _LIBOBJC
-/* Objective C.  */
+/* Objective-C.  */
 #pragma weak pthread_cond_broadcast
 #pragma weak pthread_cond_destroy
 #pragma weak pthread_cond_init
Index: gthr-posix.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gthr-posix.h,v
retrieving revision 1.22
diff -u -r1.22 gthr-posix.h
--- gthr-posix.h	4 Jun 2002 11:30:44 -0000	1.22
+++ gthr-posix.h	26 Sep 2002 22:18:13 -0000
@@ -57,7 +57,7 @@
 #pragma weak pthread_mutex_unlock
 
 #ifdef _LIBOBJC
-/* Objective C.  */
+/* Objective-C.  */
 #pragma weak pthread_cond_broadcast
 #pragma weak pthread_cond_destroy
 #pragma weak pthread_cond_init
Index: output.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/output.h,v
retrieving revision 1.112
diff -u -r1.112 output.h
--- output.h	16 Sep 2002 18:12:36 -0000	1.112
+++ output.h	26 Sep 2002 22:18:18 -0000
@@ -327,7 +327,7 @@
 
 /* Assemble the integer constant X into an object of SIZE bytes.  ALIGN is
    the alignment of the integer in bits.  Return 1 if we were able to output
-   the constant, otherwise 0.  If FORCE is non-zero, abort if we can't output
+   the constant, otherwise 0.  If FORCE is nonzero, abort if we can't output
    the constant.  */
 extern bool assemble_integer		PARAMS ((rtx, unsigned, unsigned, int));
 
Index: profile.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/profile.c,v
retrieving revision 1.98
diff -u -r1.98 profile.c
--- profile.c	8 Sep 2002 12:47:27 -0000	1.98
+++ profile.c	26 Sep 2002 22:18:19 -0000
@@ -162,7 +162,7 @@
 static basic_block find_group PARAMS ((basic_block));
 static void union_groups PARAMS ((basic_block, basic_block));
 
-/* If non-zero, we need to output a constructor to set up the
+/* If nonzero, we need to output a constructor to set up the
    per-object-file data.  */
 static int need_func_profiler = 0;
 
Index: ra-rewrite.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ra-rewrite.c,v
retrieving revision 1.5
diff -u -r1.5 ra-rewrite.c
--- ra-rewrite.c	2 Aug 2002 11:44:54 -0000	1.5
+++ ra-rewrite.c	26 Sep 2002 22:18:25 -0000
@@ -550,7 +550,7 @@
 }
 
 /* Given two rtx' S1 and S2, either being REGs or MEMs (or SUBREGs
-   thereof), return non-zero, if they overlap.  REGs and MEMs don't
+   thereof), return nonzero, if they overlap.  REGs and MEMs don't
    overlap, and if they are MEMs they must have an easy address
    (plus (basereg) (const_inst x)), otherwise they overlap.  */
 
Index: recog.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/recog.c,v
retrieving revision 1.164
diff -u -r1.164 recog.c
--- recog.c	19 Aug 2002 18:18:12 -0000	1.164
+++ recog.c	26 Sep 2002 22:18:30 -0000
@@ -191,7 +191,7 @@
    an INSN, CALL_INSN, or JUMP_INSN, the insn will be re-recognized with
    the change in place.
 
-   IN_GROUP is non-zero if this is part of a group of changes that must be
+   IN_GROUP is nonzero if this is part of a group of changes that must be
    performed as a group.  In that case, the changes will be stored.  The
    function `apply_change_group' will validate and apply the changes.
 
@@ -856,7 +856,7 @@
    sequel.  If so, return a pointer to the innermost rtx expression in which
    it is used.
 
-   If PLOC is non-zero, *PLOC is set to the insn containing the single use.
+   If PLOC is nonzero, *PLOC is set to the insn containing the single use.
 
    This routine will return usually zero either before flow is called (because
    there will be no LOG_LINKS notes) or after reload (because the REG_DEAD
@@ -2341,7 +2341,7 @@
    This is used in final, just before printing the assembler code and by
    the routines that determine an insn's attribute.
 
-   If STRICT is a positive non-zero value, it means that we have been
+   If STRICT is a positive nonzero value, it means that we have been
    called after reload has been completed.  In that case, we must
    do all checks strictly.  If it is zero, it means that we have been called
    before reload has completed.  In that case, we first try to see if we can
Index: reg-stack.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/reg-stack.c,v
retrieving revision 1.114
diff -u -r1.114 reg-stack.c
--- reg-stack.c	16 Sep 2002 11:42:00 -0000	1.114
+++ reg-stack.c	26 Sep 2002 22:18:32 -0000
@@ -268,7 +268,7 @@
 static void record_label_references	PARAMS ((rtx, rtx));
 static bool compensate_edge		PARAMS ((edge, FILE *));
 
-/* Return non-zero if any stack register is mentioned somewhere within PAT.  */
+/* Return nonzero if any stack register is mentioned somewhere within PAT.  */
 
 static int
 stack_regs_mentioned_p (pat)
Index: regclass.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/regclass.c,v
retrieving revision 1.157
diff -u -r1.157 regclass.c
--- regclass.c	14 Sep 2002 13:12:50 -0000	1.157
+++ regclass.c	26 Sep 2002 22:18:35 -0000
@@ -220,7 +220,7 @@
 
 static int forbidden_inc_dec_class[N_REG_CLASSES];
 
-/* Indexed by n, is non-zero if (REG n) is used in an auto-inc or auto-dec
+/* Indexed by n, is nonzero if (REG n) is used in an auto-inc or auto-dec
    context.  */
 
 static char *in_inc_dec;
@@ -254,7 +254,7 @@
   struct reg_info_data *next;	/* next set of reg_info structures */
   size_t min_index;		/* minimum index # */
   size_t max_index;		/* maximum index # */
-  char used_p;			/* non-zero if this has been used previously */
+  char used_p;			/* nonzero if this has been used previously */
   reg_info data[1];		/* beginning of the reg_info data */
 };
 
@@ -1904,7 +1904,7 @@
 	}
 }
 
-/* Compute the cost of loading X into (if TO_P is non-zero) or from (if
+/* Compute the cost of loading X into (if TO_P is nonzero) or from (if
    TO_P is zero) a register of class CLASS in mode MODE.
 
    X must not be a pseudo.  */
Index: regmove.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/regmove.c,v
retrieving revision 1.132
diff -u -r1.132 regmove.c
--- regmove.c	15 Jul 2002 23:59:01 -0000	1.132
+++ regmove.c	26 Sep 2002 22:18:37 -0000
@@ -80,7 +80,7 @@
 static int replacement_quality PARAMS ((rtx));
 static int fixup_match_2 PARAMS ((rtx, rtx, rtx, rtx, FILE *));
 
-/* Return non-zero if registers with CLASS1 and CLASS2 can be merged without
+/* Return nonzero if registers with CLASS1 and CLASS2 can be merged without
    causing too much register allocation problems.  */
 static int
 regclass_compatible_p (class0, class1)
Index: reload.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/reload.h,v
retrieving revision 1.40
diff -u -r1.40 reload.h
--- reload.h	16 Sep 2002 11:42:00 -0000	1.40
+++ reload.h	26 Sep 2002 22:18:44 -0000
@@ -270,7 +270,7 @@
 /* IN_RTX is the value loaded by a reload that we now decided to inherit,
    or a subpart of it.  If we have any replacements registered for IN_RTX,
    chancel the reloads that were supposed to load them.
-   Return non-zero if we chanceled any reloads.  */
+   Return nonzero if we chanceled any reloads.  */
 extern int remove_address_replacements PARAMS ((rtx in_rtx));
 
 /* Like rtx_equal_p except that it allows a REG and a SUBREG to match
Index: resource.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/resource.c,v
retrieving revision 1.58
diff -u -r1.58 resource.c
--- resource.c	27 May 2002 13:45:41 -0000	1.58
+++ resource.c	26 Sep 2002 22:18:57 -0000
@@ -372,7 +372,7 @@
 	     We assume that they both use and set all registers.  Using all
 	     registers ensures that a register will not be considered dead
 	     just because it crosses a setjmp call.  A register should be
-	     considered dead only if the setjmp call returns non-zero.  */
+	     considered dead only if the setjmp call returns nonzero.  */
 	  if (find_reg_note (x, REG_SETJMP, NULL))
 	    SET_HARD_REG_SET (res->regs);
 
@@ -1178,7 +1178,7 @@
   /* Indicate what resources are required to be valid at the end of the current
      function.  The condition code never is and memory always is.  If the
      frame pointer is needed, it is and so is the stack pointer unless
-     EXIT_IGNORE_STACK is non-zero.  If the frame pointer is not needed, the
+     EXIT_IGNORE_STACK is nonzero.  If the frame pointer is not needed, the
      stack pointer is.  Registers used to return the function value are
      needed.  Registers holding global variables are needed.  */
 
Index: rtl.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/rtl.h,v
retrieving revision 1.370
diff -u -r1.370 rtl.h
--- rtl.h	20 Sep 2002 17:50:47 -0000	1.370
+++ rtl.h	26 Sep 2002 22:18:59 -0000
@@ -1103,7 +1103,7 @@
 #define MEM_SCALAR_P(RTX)						\
   (RTL_FLAG_CHECK1("MEM_SCALAR_P", (RTX), MEM)->frame_related)
 
-/* If VAL is non-zero, set MEM_IN_STRUCT_P and clear MEM_SCALAR_P in
+/* If VAL is nonzero, set MEM_IN_STRUCT_P and clear MEM_SCALAR_P in
    RTX.  Otherwise, vice versa.  Use this macro only when you are
    *sure* that you know that the MEM is in a structure, or is a
    scalar.  VAL is evaluated only once.  */
Index: optabs.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/optabs.c,v
retrieving revision 1.148
diff -u -r1.148 optabs.c
--- optabs.c	17 Sep 2002 19:02:58 -0000	1.148
+++ optabs.c	26 Sep 2002 22:18:17 -0000
@@ -2979,7 +2979,7 @@
    TARGET, OP0, and OP1 are the output and inputs of the operations,
    respectively.  OP1 may be zero for a unary operation.
 
-   EQUIV, if non-zero, is an expression to be placed into a REG_EQUAL note
+   EQUIV, if nonzero, is an expression to be placed into a REG_EQUAL note
    on the last insn.
 
    If TARGET is not a register, INSNS is simply emitted with no special
@@ -4152,7 +4152,7 @@
   return target;
 }
 
 /* Return non-zero if a conditional move of mode MODE is supported.
 
    This function is for combine so it can tell whether an insn that looks
    like a conditional move is actually supported by the hardware.  If we
@@ -4152,7 +4152,7 @@
 }
 
-/* Return non-zero if a conditional move of mode MODE is supported.
+/* Return nonzero if a conditional move of mode MODE is supported.
 
    This function is for combine so it can tell whether an insn that looks
Index: protoize.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/protoize.c,v
retrieving revision 1.76
diff -u -r1.76 protoize.c
--- protoize.c	21 Jul 2002 21:59:02 -0000	1.76
+++ protoize.c	26 Sep 2002 22:18:23 -0000
@@ -363,7 +363,7 @@
 
 static const char *pname;
 
 /* Error counter.  Will be non-zero if we should give up at the next convenient
    stopping point.  */
 
 static int errors = 0;
@@ -669,7 +669,7 @@
 }
 
 /* Give a message indicating the proper way to invoke this program and then
-   exit with non-zero status.  */
+   exit with nonzero status.  */
 
 static void
 usage ()
@@ -1437,7 +1437,7 @@
 /* Given a line from  an aux info file, and a time at which the aux info
    file it came from was created, check to see if the item described in
    the line comes from a file which has been modified since the aux info
-   file was created.  If so, return non-zero, else return zero.  */
+   file was created.  If so, return nonzero, else return zero.  */
 
 static int
 referenced_file_is_newer (l, aux_info_mtime)
@@ -3202,7 +3202,7 @@
    list that lies to the left of the one it was originally called to work
    on.  Thus, a whole set gets done in right-to-left order.
 
-   This routine returns non-zero if it thinks that it should not be trying
+   This routine returns nonzero if it thinks that it should not be trying
    to convert this particular function definition (because the name of the
    function doesn't match the one expected).  */
 
@@ -3254,7 +3254,7 @@
 
   /* Check that the function name in the header we are working on is the same
      as the one we would expect to find.  If not, issue a warning and return
-     non-zero.  */
+     nonzero.  */
 
   if (f_list_count == 0)
     {
@@ -363,7 +363,7 @@
 static const char *pname;
 
-/* Error counter.  Will be non-zero if we should give up at the next convenient
+/* Error counter.  Will be nonzero if we should give up at the next convenient
    stopping point.  */
 
Index: real.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/real.c,v
retrieving revision 1.91
diff -u -r1.91 real.c
--- real.c	23 Sep 2002 11:26:40 -0000	1.91
+++ real.c	26 Sep 2002 22:18:27 -0000
@@ -507,7 +507,7 @@
   int shift = 0, exp;
   int i, j;
 
   /* Find the first word that is non-zero.  */
   for (i = SIGSZ - 1; i >= 0; i--)
     if (r->sig[i] == 0)
       shift += HOST_BITS_PER_LONG;
@@ -522,7 +522,7 @@
       return;
     }
 
   /* Find the first bit that is non-zero.  */
   for (j = 0; ; j++)
     if (r->sig[i] & ((unsigned long)1 << (HOST_BITS_PER_LONG - 1 - j)))
       break;
@@ -2114,7 +2114,7 @@
     }
 
   /* There are P2 true significand bits, followed by one guard bit,
-     followed by one sticky bit, followed by stuff.  Fold non-zero
+     followed by one sticky bit, followed by stuff.  Fold nonzero
      stuff into the sticky bit.  */
 
   sticky = 0;
@@ -507,7 +507,7 @@
   int i, j;
 
-  /* Find the first word that is non-zero.  */
+  /* Find the first word that is nonzero.  */
   for (i = SIGSZ - 1; i >= 0; i--)
     if (r->sig[i] == 0)
@@ -522,7 +522,7 @@
     }
 
-  /* Find the first bit that is non-zero.  */
+  /* Find the first bit that is nonzero.  */
   for (j = 0; ; j++)
     if (r->sig[i] & ((unsigned long)1 << (HOST_BITS_PER_LONG - 1 - j)))
Index: reload.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/reload.c,v
retrieving revision 1.191
diff -u -r1.191 reload.c
--- reload.c	26 Sep 2002 18:21:10 -0000	1.191
+++ reload.c	26 Sep 2002 22:18:43 -0000
@@ -276,7 +276,7 @@
 #ifdef HAVE_SECONDARY_RELOADS
 
 /* Determine if any secondary reloads are needed for loading (if IN_P is
-   non-zero) or storing (if IN_P is zero) X to or from a reload register of
+   nonzero) or storing (if IN_P is zero) X to or from a reload register of
    register class RELOAD_CLASS in mode RELOAD_MODE.  If secondary reloads
    are needed, push them.
 
@@ -368,7 +368,7 @@
 
   if (icode != CODE_FOR_nothing)
     {
       /* If IN_P is non-zero, the reload register will be the output in
 	 operand 0.  If IN_P is zero, the reload register will be the input
 	 in operand 1.  Outputs should have an initial "=", which we must
 	 skip.  */
@@ -836,7 +836,7 @@
    (IN is zero for data not read, and OUT is zero for data not written.)
    INLOC and OUTLOC point to the places in the instructions where
    IN and OUT were found.
-   If IN and OUT are both non-zero, it means the same register must be used
+   If IN and OUT are both nonzero, it means the same register must be used
    to reload both IN and OUT.
 
    CLASS is a register class required for the reloaded data.
@@ -1601,7 +1601,7 @@
 /* IN_RTX is the value loaded by a reload that we now decided to inherit,
    or a subpart of it.  If we have any replacements registered for IN_RTX,
    cancel the reloads that were supposed to load them.
-   Return non-zero if we canceled any reloads.  */
+   Return nonzero if we canceled any reloads.  */
 int
 remove_address_replacements (in_rtx)
      rtx in_rtx;
@@ -1840,7 +1840,7 @@
    If FOR_REAL is -1, this should not be done, because this call
    is just to see if a register can be found, not to find and install it.
 
-   EARLYCLOBBER is non-zero if OUT is an earlyclobber operand.  This
+   EARLYCLOBBER is nonzero if OUT is an earlyclobber operand.  This
    puts an additional constraint on being able to use IN for OUT since
    IN must not appear elsewhere in the insn (it is assumed that IN itself
    is safe from the earlyclobber).  */
@@ -368,7 +368,7 @@
   if (icode != CODE_FOR_nothing)
     {
-      /* If IN_P is non-zero, the reload register will be the output in
+      /* If IN_P is nonzero, the reload register will be the output in
 	 operand 0.  If IN_P is zero, the reload register will be the input
 	 in operand 1.  Outputs should have an initial "=", which we must
Index: reload1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/reload1.c,v
retrieving revision 1.356
diff -u -r1.356 reload1.c
--- reload1.c	15 Sep 2002 22:48:01 -0000	1.356
+++ reload1.c	26 Sep 2002 22:18:52 -0000
@@ -340,7 +340,7 @@
 #define NUM_ELIMINABLE_REGS ARRAY_SIZE (reg_eliminate_1)
 
 /* Record the number of pending eliminations that have an offset not equal
-   to their initial offset.  If non-zero, we use a new copy of each
+   to their initial offset.  If nonzero, we use a new copy of each
    replacement result in any insns encountered.  */
 int num_not_at_initial_offset;
 
@@ -2118,7 +2118,7 @@
 
    INSN is the insn that it came from, if any.
 
-   INITIAL_P is non-zero if we are to set the offset to be the initial
+   INITIAL_P is nonzero if we are to set the offset to be the initial
    offset and zero if we are setting the offset of the label to be the
    current offset.  */
 
@@ -2273,7 +2273,7 @@
    to record the fact that a register is referenced outside a MEM.
 
    If INSN is an insn, it is the insn containing X.  If we replace a REG
-   in a SET_DEST with an equivalent MEM and INSN is non-zero, write a
+   in a SET_DEST with an equivalent MEM and INSN is nonzero, write a
    CLOBBER of the pseudo after INSN so find_equiv_regs will know that
    the REG is being modified.
 
@@ -4752,7 +4752,7 @@
    if we know it.  Otherwise, this is 0.  */
 rtx reload_inheritance_insn[MAX_RELOADS];
 
 /* If non-zero, this is a place to get the value of the reload,
    rather than using reload_in.  */
 rtx reload_override_in[MAX_RELOADS];
 
@@ -4993,7 +4993,7 @@
    determine how many hard regs to test.
 
    Other read-only reloads with the same value do not conflict
-   unless OUT is non-zero and these other reloads have to live while
+   unless OUT is nonzero and these other reloads have to live while
    output reloads live.
    If OUT is CONST0_RTX, this is a special case: it means that the
    test should not be for using register REGNO as reload register, but
@@ -5116,7 +5116,7 @@
 }
 
 /* Find a spill register to use as a reload register for reload R.
-   LAST_RELOAD is non-zero if this is the last reload for the insn being
+   LAST_RELOAD is nonzero if this is the last reload for the insn being
    processed.
 
    Set rld[R].reg_rtx to the register allocated.
@@ -6009,7 +6009,7 @@
   reload_spill_index[r] = -1;
 }
 
 /* If SMALL_REGISTER_CLASSES is non-zero, we may not have merged two
    reloads of the same item for fear that we might not have enough reload
    registers. However, normally they will get the same reload register
    and hence actually need not be loaded twice.
@@ -7922,7 +7922,7 @@
   rtx real_in = in == value ? XEXP (in, 0) : in;
 
   /* No hard register is equivalent to this register after
-     inc/dec operation.  If REG_LAST_RELOAD_REG were non-zero,
+     inc/dec operation.  If REG_LAST_RELOAD_REG were nonzero,
      we could inc/dec that register as well (maybe even using it for
      the source), but I'm not sure it's worth worrying about.  */
   if (GET_CODE (incloc) == REG)
@@ -4752,7 +4752,7 @@
 rtx reload_inheritance_insn[MAX_RELOADS];
 
-/* If non-zero, this is a place to get the value of the reload,
+/* If nonzero, this is a place to get the value of the reload,
    rather than using reload_in.  */
 rtx reload_override_in[MAX_RELOADS];
@@ -6009,7 +6009,7 @@
 }
 
-/* If SMALL_REGISTER_CLASSES is non-zero, we may not have merged two
+/* If SMALL_REGISTER_CLASSES is nonzero, we may not have merged two
    reloads of the same item for fear that we might not have enough reload
    registers. However, normally they will get the same reload register
Index: reorg.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/reorg.c,v
retrieving revision 1.81
diff -u -r1.81 reorg.c
--- reorg.c	23 Jul 2002 06:21:56 -0000	1.81
+++ reorg.c	26 Sep 2002 22:18:56 -0000
@@ -928,7 +928,7 @@
    taken, return 1.  If the branch is slightly less likely to be taken,
    return 0 and if the branch is highly unlikely to be taken, return -1.
 
-   CONDITION, if non-zero, is the condition that JUMP_INSN is testing.  */
+   CONDITION, if nonzero, is the condition that JUMP_INSN is testing.  */
 
 static int
 mostly_true_jump (jump_insn, condition)
@@ -1098,7 +1098,7 @@
   return 0;
 }
 
 /* Return non-zero if CONDITION is more strict than the condition of
    INSN, i.e., if INSN will always branch if CONDITION is true.  */
 
 static int
@@ -1126,7 +1126,7 @@
   return comparison_dominates_p (code, other_code);
 }
 
 /* Return non-zero if redirecting JUMP to NEWLABEL does not invalidate
    any insns already in the delay slot of JUMP.  */
 
 static int
@@ -1138,7 +1138,7 @@
 
   /* Make sure all the delay slots of this jump would still
      be valid after threading the jump.  If they are still
-     valid, then return non-zero.  */
+     valid, then return nonzero.  */
 
   flags = get_jump_flags (jump, newlabel);
   for (i = 1; i < XVECLEN (pat, 0); i++)
@@ -1161,7 +1161,7 @@
   return (i == XVECLEN (pat, 0));
 }
 
 /* Return non-zero if redirecting JUMP to NEWLABEL does not invalidate
    any insns we wish to place in the delay slot of JUMP.  */
 
 static int
@@ -1173,7 +1173,7 @@
 
   /* Make sure all the insns in DELAY_LIST would still be
      valid after threading the jump.  If they are still
-     valid, then return non-zero.  */
+     valid, then return nonzero.  */
 
   flags = get_jump_flags (jump, newlabel);
   for (li = delay_list, i = 0; li; li = XEXP (li, 1), i++)
@@ -1233,9 +1233,9 @@
    insns in DELAY_LIST).  It is updated with the number that have been
    filled from the SEQUENCE, if any.
 
-   PANNUL_P points to a non-zero value if we already know that we need
+   PANNUL_P points to a nonzero value if we already know that we need
    to annul INSN.  If this routine determines that annulling is needed,
-   it may set that value non-zero.
+   it may set that value nonzero.
 
    PNEW_THREAD points to a location that is to receive the place at which
    execution should continue.  */
@@ -1856,9 +1856,9 @@
   return 0;
 }
 
 /* Return 1 if THREAD can only be executed in one way.  If LABEL is non-zero,
    it is the target of the branch insn being scanned.  If ALLOW_FALLTHROUGH
-   is non-zero, we are allowed to fall into this thread; otherwise, we are
+   is nonzero, we are allowed to fall into this thread; otherwise, we are
    not.
 
    If LABEL is used more than one or we pass a label other than LABEL before
@@ -2040,7 +2040,7 @@
 /* Scan a function looking for insns that need a delay slot and find insns to
    put into the delay slot.
 
-   NON_JUMPS_P is non-zero if we are to only try to fill non-jump insns (such
+   NON_JUMPS_P is nonzero if we are to only try to fill non-jump insns (such
    as calls).  We do these first since we don't want jump insns (that are
    easier to fill) to get the only insns that could be used for non-jump insns.
    When it is zero, only try to fill JUMP_INSNs.
@@ -2543,7 +2543,7 @@
    OPPOSITE_THREAD is the thread in the opposite direction.  It is used
    to see if any potential delay slot insns set things needed there.
 
-   LIKELY is non-zero if it is extremely likely that the branch will be
+   LIKELY is nonzero if it is extremely likely that the branch will be
    taken and THREAD_IF_TRUE is set.  This is used for the branch at the
    end of a loop back up to the top.
 
@@ -1098,7 +1098,7 @@
 }
 
-/* Return non-zero if CONDITION is more strict than the condition of
+/* Return nonzero if CONDITION is more strict than the condition of
    INSN, i.e., if INSN will always branch if CONDITION is true.  */
 
@@ -1126,7 +1126,7 @@
 }
 
-/* Return non-zero if redirecting JUMP to NEWLABEL does not invalidate
+/* Return nonzero if redirecting JUMP to NEWLABEL does not invalidate
    any insns already in the delay slot of JUMP.  */
 
@@ -1161,7 +1161,7 @@
 }
 
-/* Return non-zero if redirecting JUMP to NEWLABEL does not invalidate
+/* Return nonzero if redirecting JUMP to NEWLABEL does not invalidate
    any insns we wish to place in the delay slot of JUMP.  */
 
@@ -1856,9 +1856,9 @@
 }
 
-/* Return 1 if THREAD can only be executed in one way.  If LABEL is non-zero,
+/* Return 1 if THREAD can only be executed in one way.  If LABEL is nonzero,
    it is the target of the branch insn being scanned.  If ALLOW_FALLTHROUGH
Index: rtlanal.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/rtlanal.c,v
retrieving revision 1.139
diff -u -r1.139 rtlanal.c
--- rtlanal.c	7 Sep 2002 09:59:16 -0000	1.139
+++ rtlanal.c	26 Sep 2002 22:19:02 -0000
@@ -353,7 +353,7 @@
    into the jump table.  If the offset cannot be determined, then return
    NULL_RTX.
 
-   If EARLIEST is non-zero, it is a pointer to a place where the earliest
+   If EARLIEST is nonzero, it is a pointer to a place where the earliest
    insn used in locating the offset was found.  */
 
 rtx
@@ -541,7 +541,7 @@
   return 0;
 }
 
 /* Returns non-zero if X mentions a global register.  */
 
 int
 global_reg_mentioned_p (x)
@@ -2786,7 +2786,7 @@
    sub-expression (including X itself).  F is also passed the DATA.
    If F returns -1, do not traverse sub-expressions, but continue
    traversing the rest of the tree.  If F ever returns any other
-   non-zero value, stop the traversal, and return the value returned
+   nonzero value, stop the traversal, and return the value returned
    by F.  Otherwise, return 0.  This function does not traverse inside
    tree structure that contains RTX_EXPRs, or into sub-expressions
    whose format code is `0' since it is not known whether or not those
@@ -3039,7 +3039,7 @@
   return 0;
 }
 
 /* Return non-zero if IN contains a piece of rtl that has the address LOC */
 int
 loc_mentioned_in_p (loc, in)
      rtx *loc, in;
@@ -541,7 +541,7 @@
 }
 
-/* Returns non-zero if X mentions a global register.  */
+/* Returns nonzero if X mentions a global register.  */
 
 int
@@ -3039,7 +3039,7 @@
 }
 
-/* Return non-zero if IN contains a piece of rtl that has the address LOC */
+/* Return nonzero if IN contains a piece of rtl that has the address LOC */
 int
 loc_mentioned_in_p (loc, in)


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]